@@ -49,6 +49,12 @@ pub enum AwsCredentialFeature {
     CredentialsImds,
     /// An operation called using a Bearer token resolved from service-specific environment variables
     BearerServiceEnvVars,
+    /// An operation called using S3 Express bucket credentials
+    S3ExpressBucket,
+    /// An operation called using credentials resolved from a LoginCredentialsProvider configured via profile
+    CredentialsProfileLogin,
+    /// An operation called using credentials resolved from a LoginCredentialsProvider configured explicitly via code
+    CredentialsLogin,
 }
 
 impl Storable for AwsCredentialFeature {
