@@ -324,7 +324,7 @@ fn js_error(item: TokenStream) -> Result<TokenStream, Error> {
       ) -> ::deno_error::AdditionalProperties {
         #properties
       }
-      fn as_any(&self) -> &dyn ::std::any::Any {
+      fn get_ref(&self) -> &(dyn ::std::error::Error + Send + Sync + 'static) {
         self
       }
     }
@@ -364,7 +364,7 @@ fn handle_variant_or_struct(
         let ident_str = &property.name;
 
         quote! {
-          (::std::borrow::Cow::Borrowed(#ident_str), #i.into()),
+          (::std::borrow::Cow::Borrowed(#ident_str), #i.into())
         }
       })
       .collect::<Vec<_>>();
