@@ -49,6 +49,7 @@ pub struct RequestOptions {
     retry_throttler: Option<SharedRetryThrottler>,
     polling_error_policy: Option<Arc<dyn PollingErrorPolicy>>,
     polling_backoff_policy: Option<Arc<dyn PollingBackoffPolicy>>,
+    path_template: Option<&'static str>,
 }
 
 impl RequestOptions {
@@ -153,6 +154,16 @@ impl RequestOptions {
     pub fn set_polling_backoff_policy<V: Into<PollingBackoffPolicyArg>>(&mut self, v: V) {
         self.polling_backoff_policy = Some(v.into().0);
     }
+
+    /// Get the current path template, if any.
+    pub(crate) fn path_template(&self) -> Option<&'static str> {
+        self.path_template
+    }
+
+    /// Sets the path template for the request URL.
+    pub(crate) fn set_path_template(&mut self, v: &'static str) {
+        self.path_template = Some(v);
+    }
 }
 
 /// Implementations of this trait provide setters to configure request options.
@@ -211,6 +222,18 @@ pub mod internal {
         options.set_default_idempotency(default);
         options
     }
+
+    pub fn set_path_template(
+        mut options: RequestOptions,
+        path_template: &'static str,
+    ) -> RequestOptions {
+        options.set_path_template(path_template);
+        options
+    }
+
+    pub fn get_path_template(options: &RequestOptions) -> Option<&'static str> {
+        options.path_template()
+    }
 }
 
 /// Implements the sealed [RequestOptionsBuilder] trait.
@@ -313,6 +336,9 @@ mod tests {
 
         opts.set_polling_backoff_policy(ExponentialBackoffBuilder::new().clamp());
         assert!(opts.polling_backoff_policy().is_some(), "{opts:?}");
+
+        opts.set_path_template("test");
+        assert_eq!(opts.path_template(), Some("test"));
     }
 
     #[test]
@@ -328,6 +354,14 @@ mod tests {
         assert_eq!(opts.idempotent(), Some(false));
     }
 
+    #[test]
+    fn request_options_path_template() {
+        let opts = RequestOptions::default();
+        assert_eq!(opts.path_template(), None);
+        let opts = set_path_template(opts, "test");
+        assert_eq!(opts.path_template(), Some("test"));
+    }
+
     #[test]
     fn request_options_builder() -> Result {
         let mut builder = TestBuilder::default();
