@@ -37,20 +37,15 @@
 //!
 
 use crate::{
+    diagnostic::{diagnostic_url, Diagnostic, Label},
     index::{OutOfBoundsError, ParseIndexError},
-    Pointer,
+    Pointer, PointerBuf,
+};
+use alloc::{boxed::Box, string::ToString};
+use core::{
+    fmt::{self, Debug},
+    iter::once,
 };
-use core::fmt::{self, Debug};
-
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                    Assign                                    ║
-║                                   ¯¯¯¯¯¯¯¯                                   ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
 
 /// Implemented by types which can internally assign a
 /// ([`Value`](`Assign::Value`)) at a path represented by a JSON [`Pointer`].
@@ -129,31 +124,33 @@ pub trait Assign {
         V: Into<Self::Value>;
 }
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                 AssignError                                  ║
-║                                ¯¯¯¯¯¯¯¯¯¯¯¯¯                                 ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
+/// Alias for [`Error`] - indicates a value assignment failed.
+#[deprecated(since = "0.7.0", note = "renamed to `Error`")]
+pub type AssignError = Error;
 
 /// Possible error returned from [`Assign`] implementations for
 /// [`serde_json::Value`] and
 /// [`toml::Value`](https://docs.rs/toml/0.8.14/toml/index.html).
 #[derive(Debug, PartialEq, Eq)]
-pub enum AssignError {
-    /// A `Token` within the `Pointer` failed to be parsed as an array index.
+pub enum Error {
+    /// A [`Token`](crate::Token) within the [`Pointer`] failed to be parsed as
+    /// an array index.
     FailedToParseIndex {
+        /// Position (index) of the token which failed to parse as an [`Index`](crate::index::Index)
+        position: usize,
         /// Offset of the partial pointer starting with the invalid index.
         offset: usize,
         /// The source [`ParseIndexError`]
         source: ParseIndexError,
     },
 
-    /// target array.
+    /// A [`Token`](crate::Token) within the [`Pointer`] contains an
+    /// [`Index`](crate::index::Index) which is out of bounds.
+    ///
+    /// The current or resulting array's length is less than the index.
     OutOfBounds {
+        /// Position (index) of the token which failed to parse as an [`Index`](crate::index::Index)
+        position: usize,
         /// Offset of the partial pointer starting with the invalid index.
         offset: usize,
         /// The source [`OutOfBoundsError`]
@@ -161,27 +158,91 @@ pub enum AssignError {
     },
 }
 
-impl fmt::Display for AssignError {
+impl Error {
+    /// The position (token index) of the [`Token`](crate::Token) which was out of bounds
+    pub fn position(&self) -> usize {
+        match self {
+            Self::OutOfBounds { position, .. } | Self::FailedToParseIndex { position, .. } => {
+                *position
+            }
+        }
+    }
+    /// Offset (in bytes) of the partial pointer starting with the invalid token.
+    pub fn offset(&self) -> usize {
+        match self {
+            Self::OutOfBounds { offset, .. } | Self::FailedToParseIndex { offset, .. } => *offset,
+        }
+    }
+
+    /// Returns `true` if the error is [`OutOfBounds`].
+    ///
+    /// [`OutOfBounds`]: Error::OutOfBounds
+    #[must_use]
+    pub fn is_out_of_bounds(&self) -> bool {
+        matches!(self, Self::OutOfBounds { .. })
+    }
+
+    /// Returns `true` if the error is [`FailedToParseIndex`].
+    ///
+    /// [`FailedToParseIndex`]: Error::FailedToParseIndex
+    #[must_use]
+    pub fn is_failed_to_parse_index(&self) -> bool {
+        matches!(self, Self::FailedToParseIndex { .. })
+    }
+}
+
+impl fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
             Self::FailedToParseIndex { offset, .. } => {
                 write!(
                     f,
-                    "assignment failed due to an invalid index at offset {offset}"
-                )
-            }
-            Self::OutOfBounds { offset, .. } => {
-                write!(
-                    f,
-                    "assignment failed due to index at offset {offset} being out of bounds"
+                    "assign failed: json pointer token at offset {offset} failed to parse as an array index"
                 )
             }
+            Self::OutOfBounds { offset, .. } => write!(
+                f,
+                "assign failed: json pointer token at offset {offset} is out of bounds",
+            ),
         }
     }
 }
 
+impl Diagnostic for Error {
+    type Subject = PointerBuf;
+
+    fn url() -> &'static str {
+        diagnostic_url!(enum assign::Error)
+    }
+
+    fn labels(&self, origin: &Self::Subject) -> Option<Box<dyn Iterator<Item = Label>>> {
+        let position = self.position();
+        let token = origin.get(position)?;
+        let offset = if self.offset() + 1 < origin.as_str().len() {
+            self.offset() + 1
+        } else {
+            self.offset()
+        };
+        let len = token.encoded().len();
+        let text = match self {
+            Error::FailedToParseIndex { .. } => "expected array index or '-'".to_string(),
+            Error::OutOfBounds { source, .. } => {
+                format!("{} is out of bounds (len: {})", source.index, source.length)
+            }
+        };
+        Some(Box::new(once(Label::new(text, offset, len))))
+    }
+}
+
+#[cfg(feature = "miette")]
+impl miette::Diagnostic for Error {
+    fn url<'a>(&'a self) -> Option<Box<dyn fmt::Display + 'a>> {
+        Some(Box::new(<Self as Diagnostic>::url()))
+    }
+}
+
 #[cfg(feature = "std")]
-impl std::error::Error for AssignError {
+impl std::error::Error for Error {
     fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
         match self {
             Self::FailedToParseIndex { source, .. } => Some(source),
@@ -190,24 +251,9 @@ impl std::error::Error for AssignError {
     }
 }
 
-enum Assigned<'v, V> {
-    Done(Option<V>),
-    Continue { next_dest: &'v mut V, same_value: V },
-}
-
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                  json impl                                   ║
-║                                 ¯¯¯¯¯¯¯¯¯¯¯                                  ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
-
 #[cfg(feature = "json")]
 mod json {
-    use super::{Assign, AssignError, Assigned};
+    use super::{Assign, Assigned, Error};
     use crate::{Pointer, Token};
     use alloc::{
         string::{String, ToString},
@@ -235,7 +281,7 @@ mod json {
     }
     impl Assign for Value {
         type Value = Value;
-        type Error = AssignError;
+        type Error = Error;
         fn assign<V>(&mut self, ptr: &Pointer, value: V) -> Result<Option<Self::Value>, Self::Error>
         where
             V: Into<Self::Value>,
@@ -248,14 +294,15 @@ mod json {
         mut ptr: &Pointer,
         mut dest: &mut Value,
         mut value: Value,
-    ) -> Result<Option<Value>, AssignError> {
+    ) -> Result<Option<Value>, Error> {
         let mut offset = 0;
 
+        let mut position = 0;
         while let Some((token, tail)) = ptr.split_front() {
             let tok_len = token.encoded().len();
 
             let assigned = match dest {
-                Value::Array(array) => assign_array(token, tail, array, value, offset)?,
+                Value::Array(array) => assign_array(token, tail, array, value, position, offset)?,
                 Value::Object(obj) => assign_object(token, tail, obj, value),
                 _ => assign_scalar(ptr, dest, value),
             };
@@ -273,6 +320,7 @@ mod json {
                 }
             }
             offset += 1 + tok_len;
+            position += 1;
         }
 
         // Pointer is root, we can replace `dest` directly
@@ -285,14 +333,23 @@ mod json {
         remaining: &Pointer,
         array: &'v mut Vec<Value>,
         src: Value,
+        position: usize,
         offset: usize,
-    ) -> Result<Assigned<'v, Value>, AssignError> {
+    ) -> Result<Assigned<'v, Value>, Error> {
         // parsing the index
         let idx = token
             .to_index()
-            .map_err(|source| AssignError::FailedToParseIndex { offset, source })?
+            .map_err(|source| Error::FailedToParseIndex {
+                position,
+                offset,
+                source,
+            })?
             .for_len_incl(array.len())
-            .map_err(|source| AssignError::OutOfBounds { offset, source })?;
+            .map_err(|source| Error::OutOfBounds {
+                position,
+                offset,
+                source,
+            })?;
 
         debug_assert!(idx <= array.len());
 
@@ -369,19 +426,9 @@ mod json {
     }
 }
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                  toml impl                                   ║
-║                                 ¯¯¯¯¯¯¯¯¯¯¯                                  ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
-
 #[cfg(feature = "toml")]
 mod toml {
-    use super::{Assign, AssignError, Assigned};
+    use super::{Assign, Assigned, Error};
     use crate::{Pointer, Token};
     use alloc::{string::String, vec, vec::Vec};
     use core::mem;
@@ -406,7 +453,7 @@ mod toml {
 
     impl Assign for Value {
         type Value = Value;
-        type Error = AssignError;
+        type Error = Error;
         fn assign<V>(&mut self, ptr: &Pointer, value: V) -> Result<Option<Self::Value>, Self::Error>
         where
             V: Into<Self::Value>,
@@ -419,14 +466,15 @@ mod toml {
         mut ptr: &Pointer,
         mut dest: &mut Value,
         mut value: Value,
-    ) -> Result<Option<Value>, AssignError> {
+    ) -> Result<Option<Value>, Error> {
         let mut offset = 0;
+        let mut position = 0;
 
         while let Some((token, tail)) = ptr.split_front() {
             let tok_len = token.encoded().len();
 
             let assigned = match dest {
-                Value::Array(array) => assign_array(token, tail, array, value, offset)?,
+                Value::Array(array) => assign_array(token, tail, array, value, position, offset)?,
                 Value::Table(tbl) => assign_object(token, tail, tbl, value),
                 _ => assign_scalar(ptr, dest, value),
             };
@@ -444,6 +492,7 @@ mod toml {
                 }
             }
             offset += 1 + tok_len;
+            position += 1;
         }
 
         // Pointer is root, we can replace `dest` directly
@@ -457,14 +506,23 @@ mod toml {
         remaining: &Pointer,
         array: &'v mut Vec<Value>,
         src: Value,
+        position: usize,
         offset: usize,
-    ) -> Result<Assigned<'v, Value>, AssignError> {
+    ) -> Result<Assigned<'v, Value>, Error> {
         // parsing the index
         let idx = token
             .to_index()
-            .map_err(|source| AssignError::FailedToParseIndex { offset, source })?
+            .map_err(|source| Error::FailedToParseIndex {
+                position,
+                offset,
+                source,
+            })?
             .for_len_incl(array.len())
-            .map_err(|source| AssignError::OutOfBounds { offset, source })?;
+            .map_err(|source| Error::OutOfBounds {
+                position,
+                offset,
+                source,
+            })?;
 
         debug_assert!(idx <= array.len());
 
@@ -537,25 +595,20 @@ mod toml {
     }
 }
 
-/*
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-╔══════════════════════════════════════════════════════════════════════════════╗
-║                                                                              ║
-║                                    Tests                                     ║
-║                                   ¯¯¯¯¯¯¯                                    ║
-╚══════════════════════════════════════════════════════════════════════════════╝
-░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░
-*/
+enum Assigned<'v, V> {
+    Done(Option<V>),
+    Continue { next_dest: &'v mut V, same_value: V },
+}
 
 #[cfg(test)]
 #[allow(clippy::too_many_lines)]
 mod tests {
-    use super::{Assign, AssignError};
+    use super::{Assign, Error};
     use crate::{
-        index::{OutOfBoundsError, ParseIndexError},
+        index::{InvalidCharacterError, OutOfBoundsError, ParseIndexError},
         Pointer,
     };
-    use alloc::str::FromStr;
+    use alloc::vec;
     use core::fmt::{Debug, Display};
 
     #[derive(Debug)]
@@ -574,9 +627,6 @@ mod tests {
         V::Error: Debug + PartialEq,
         Result<Option<V>, V::Error>: PartialEq<Result<Option<V::Value>, V::Error>>,
     {
-        fn all(tests: impl IntoIterator<Item = Test<V>>) {
-            tests.into_iter().enumerate().for_each(|(i, t)| t.run(i));
-        }
         fn run(self, i: usize) {
             let Test {
                 ptr,
@@ -596,18 +646,11 @@ mod tests {
         }
     }
 
-    /*
-    ╔═══════════════════════════════════════════════════╗
-    ║                        json                       ║
-    ╚═══════════════════════════════════════════════════╝
-    */
-
     #[test]
     #[cfg(feature = "json")]
     fn assign_json() {
-        use alloc::vec;
         use serde_json::json;
-        Test::all([
+        [
             Test {
                 ptr: "/foo",
                 data: json!({}),
@@ -731,7 +774,8 @@ mod tests {
                 ptr: "/1",
                 data: json!([]),
                 assign: json!("foo"),
-                expected: Err(AssignError::OutOfBounds {
+                expected: Err(Error::OutOfBounds {
+                    position: 0,
                     offset: 0,
                     source: OutOfBoundsError {
                         index: 1,
@@ -748,12 +792,16 @@ mod tests {
                 expected_data: json!(["bar"]),
             },
             Test {
-                ptr: "/a",
+                ptr: "/12a",
                 data: json!([]),
                 assign: json!("foo"),
-                expected: Err(AssignError::FailedToParseIndex {
+                expected: Err(Error::FailedToParseIndex {
+                    position: 0,
                     offset: 0,
-                    source: ParseIndexError::InvalidInteger(usize::from_str("foo").unwrap_err()),
+                    source: ParseIndexError::InvalidCharacter(InvalidCharacterError {
+                        source: "12a".into(),
+                        offset: 2,
+                    }),
                 }),
                 expected_data: json!([]),
             },
@@ -761,27 +809,38 @@ mod tests {
                 ptr: "/002",
                 data: json!([]),
                 assign: json!("foo"),
-                expected: Err(AssignError::FailedToParseIndex {
+                expected: Err(Error::FailedToParseIndex {
+                    position: 0,
                     offset: 0,
                     source: ParseIndexError::LeadingZeros,
                 }),
                 expected_data: json!([]),
             },
-        ]);
+            Test {
+                ptr: "/+23",
+                data: json!([]),
+                assign: json!("foo"),
+                expected: Err(Error::FailedToParseIndex {
+                    position: 0,
+                    offset: 0,
+                    source: ParseIndexError::InvalidCharacter(InvalidCharacterError {
+                        source: "+23".into(),
+                        offset: 0,
+                    }),
+                }),
+                expected_data: json!([]),
+            },
+        ]
+        .into_iter()
+        .enumerate()
+        .for_each(|(i, t)| t.run(i));
     }
 
-    /*
-    ╔══════════════════════════════════════════════════╗
-    ║                       toml                       ║
-    ╚══════════════════════════════════════════════════╝
-    */
-
     #[test]
     #[cfg(feature = "toml")]
     fn assign_toml() {
-        use alloc::vec;
         use toml::{toml, Table, Value};
-        Test::all([
+        [
             Test {
                 data: Value::Table(toml::Table::new()),
                 ptr: "/foo",
@@ -900,7 +959,8 @@ mod tests {
                 data: Value::Array(vec![]),
                 ptr: "/1",
                 assign: "foo".into(),
-                expected: Err(AssignError::OutOfBounds {
+                expected: Err(Error::OutOfBounds {
+                    position: 0,
                     offset: 0,
                     source: OutOfBoundsError {
                         index: 1,
@@ -913,12 +973,19 @@ mod tests {
                 data: Value::Array(vec![]),
                 ptr: "/a",
                 assign: "foo".into(),
-                expected: Err(AssignError::FailedToParseIndex {
+                expected: Err(Error::FailedToParseIndex {
+                    position: 0,
                     offset: 0,
-                    source: ParseIndexError::InvalidInteger(usize::from_str("foo").unwrap_err()),
+                    source: ParseIndexError::InvalidCharacter(InvalidCharacterError {
+                        source: "a".into(),
+                        offset: 0,
+                    }),
                 }),
                 expected_data: Value::Array(vec![]),
             },
-        ]);
+        ]
+        .into_iter()
+        .enumerate()
+        .for_each(|(i, t)| t.run(i));
     }
 }
