@@ -33,15 +33,13 @@ use std::sync::Arc;
 use crate::error::RegisterMethodError;
 use crate::id_providers::RandomIntegerIdProvider;
 use crate::server::helpers::MethodSink;
-use crate::server::method_response::MethodResponse;
 use crate::server::subscription::{
-	sub_message_to_json, BoundedSubscriptions, IntoSubscriptionCloseResponse, PendingSubscriptionSink,
-	SubNotifResultOrError, Subscribers, Subscription, SubscriptionCloseResponse, SubscriptionKey, SubscriptionPermit,
-	SubscriptionState,
+	BoundedSubscriptions, IntoSubscriptionCloseResponse, PendingSubscriptionSink, Subscribers, Subscription,
+	SubscriptionCloseResponse, SubscriptionKey, SubscriptionPermit, SubscriptionState, sub_message_to_json,
 };
-use crate::server::{ResponsePayload, LOG_TARGET};
+use crate::server::{LOG_TARGET, MethodResponse, ResponsePayload};
 use crate::traits::ToRpcParams;
-use futures_util::{future::BoxFuture, FutureExt};
+use futures_util::{FutureExt, future::BoxFuture};
 use http::Extensions;
 use jsonrpsee_types::error::{ErrorCode, ErrorObject};
 use jsonrpsee_types::{
@@ -49,9 +47,10 @@ use jsonrpsee_types::{
 };
 use rustc_hash::FxHashMap;
 use serde::de::DeserializeOwned;
+use serde_json::value::RawValue;
 use tokio::sync::{mpsc, oneshot};
 
-use super::IntoResponse;
+use super::{IntoResponse, sub_err_to_json};
 
 /// A `MethodCallback` is an RPC endpoint, callable with a standard JSON-RPC request,
 /// implemented as a function pointer to a `Fn` function taking four arguments:
@@ -95,7 +94,7 @@ pub type MaxResponseSize = usize;
 /// A tuple containing:
 ///   - Call result as a `String`,
 ///   - a [`mpsc::UnboundedReceiver<String>`] to receive future subscription results
-pub type RawRpcResponse = (String, mpsc::Receiver<String>);
+pub type RawRpcResponse = (Box<RawValue>, mpsc::Receiver<Box<RawValue>>);
 
 /// The error that can occur when [`Methods::call`] or [`Methods::subscribe`] is invoked.
 #[derive(thiserror::Error, Debug)]
@@ -307,11 +306,11 @@ impl Methods {
 		params: Params,
 	) -> Result<T, MethodsError> {
 		let params = params.to_rpc_params()?;
-		let req = Request::new(method.into(), params.as_ref().map(|p| p.as_ref()), Id::Number(0));
+		let req = Request::borrowed(method, params.as_ref().map(|p| p.as_ref()), Id::Number(0));
 		tracing::trace!(target: LOG_TARGET, "[Methods::call] Method: {:?}, params: {:?}", method, params);
 		let (rp, _) = self.inner_call(req, 1, mock_subscription_permit()).await;
 
-		let rp = serde_json::from_str::<Response<T>>(&rp)?;
+		let rp = serde_json::from_str::<Response<T>>(rp.get())?;
 		ResponseSuccess::try_from(rp).map(|s| s.result).map_err(|e| MethodsError::JsonRpc(e.into_owned()))
 	}
 
@@ -326,6 +325,7 @@ impl Methods {
 	/// async fn main() {
 	///     use jsonrpsee::{RpcModule, SubscriptionMessage};
 	///     use jsonrpsee::types::{response::Success, Response};
+	///     use jsonrpsee::core::to_json_raw_value;
 	///     use futures_util::StreamExt;
 	///
 	///     let mut module = RpcModule::new(());
@@ -333,17 +333,18 @@ impl Methods {
 	///         let sink = pending.accept().await?;
 	///
 	///         // see comment above.
-	///         sink.send("one answer".into()).await?;
+	///         let msg = to_json_raw_value(&"one answer").unwrap();
+	///         sink.send(msg).await?;
 	///
 	///         Ok(())
 	///     }).unwrap();
 	///     let (resp, mut stream) = module.raw_json_request(r#"{"jsonrpc":"2.0","method":"hi","id":0}"#, 1).await.unwrap();
 	///     // If the response is an error converting it to `Success` will fail.
-	///     let resp: Success<u64> = serde_json::from_str::<Response<u64>>(&resp).unwrap().try_into().unwrap();
+	///     let resp: Success<u64> = serde_json::from_str::<Response<u64>>(resp.get()).unwrap().try_into().unwrap();
 	///     let sub_resp = stream.recv().await.unwrap();
 	///     assert_eq!(
 	///         format!(r#"{{"jsonrpc":"2.0","method":"hi","params":{{"subscription":{},"result":"one answer"}}}}"#, resp.result),
-	///         sub_resp
+	///         sub_resp.get()
 	///     );
 	/// }
 	/// ```
@@ -351,7 +352,7 @@ impl Methods {
 		&self,
 		request: &str,
 		buf_size: usize,
-	) -> Result<(String, mpsc::Receiver<String>), serde_json::Error> {
+	) -> Result<(Box<RawValue>, mpsc::Receiver<Box<RawValue>>), serde_json::Error> {
 		tracing::trace!("[Methods::raw_json_request] Request: {:?}", request);
 		let req: Request = serde_json::from_str(request)?;
 		let (resp, rx) = self.inner_call(req, buf_size, mock_subscription_permit()).await;
@@ -399,7 +400,7 @@ impl Methods {
 		};
 
 		let is_success = response.is_success();
-		let (rp, notif) = response.into_parts();
+		let (rp, notif, _) = response.into_parts();
 
 		if let Some(n) = notif {
 			n.notify(is_success);
@@ -422,12 +423,13 @@ impl Methods {
 	/// #[tokio::main]
 	/// async fn main() {
 	///     use jsonrpsee::{RpcModule, SubscriptionMessage};
-	///     use jsonrpsee::core::{EmptyServerParams, RpcResult};
+	///     use jsonrpsee::core::{EmptyServerParams, RpcResult, to_json_raw_value};
 	///
 	///     let mut module = RpcModule::new(());
 	///     module.register_subscription("hi", "hi", "goodbye", |_, pending, _, _| async move {
 	///         let sink = pending.accept().await?;
-	///         sink.send("one answer".into()).await?;
+	///         let msg = to_json_raw_value(&"one answer").unwrap();
+	///         sink.send(msg).await?;
 	///         Ok(())
 	///     }).unwrap();
 	///
@@ -455,18 +457,15 @@ impl Methods {
 		buf_size: usize,
 	) -> Result<Subscription, MethodsError> {
 		let params = params.to_rpc_params()?;
-		let req = Request::new(sub_method.into(), params.as_ref().map(|p| p.as_ref()), Id::Number(0));
+		let req = Request::borrowed(sub_method, params.as_ref().map(|p| p.as_ref()), Id::Number(0));
 
 		tracing::trace!(target: LOG_TARGET, "[Methods::subscribe] Method: {}, params: {:?}", sub_method, params);
 
 		let (resp, rx) = self.inner_call(req, buf_size, mock_subscription_permit()).await;
+		let as_success: ResponseSuccess<&RawValue> = serde_json::from_str::<Response<_>>(resp.get())?.try_into()?;
+		let sub_id: RpcSubscriptionId = serde_json::from_str(as_success.result.get())?;
 
-		// TODO: hack around the lifetime on the `SubscriptionId` by deserialize first to serde_json::Value.
-		let as_success: ResponseSuccess<serde_json::Value> = serde_json::from_str::<Response<_>>(&resp)?.try_into()?;
-
-		let sub_id = as_success.result.try_into().map_err(|_| MethodsError::InvalidSubscriptionId(resp.clone()))?;
-
-		Ok(Subscription { sub_id, rx })
+		Ok(Subscription { sub_id: sub_id.into_owned(), rx })
 	}
 
 	/// Returns an `Iterator` with all the method names registered on this server.
@@ -770,7 +769,7 @@ impl<Context: Send + Sync + 'static> RpcModule<Context> {
 	///     //
 	///     // If you need some other behavior implement or custom format of the error field
 	///     // you need to manually handle that.
-	///     let msg = SubscriptionMessage::from_json(&sum)?;
+	///     let msg = serde_json::value::to_raw_value(&sum).unwrap();
 	///
 	///     // This fails only if the connection is closed
 	///     sink.send(msg).await?;
@@ -841,11 +840,11 @@ impl<Context: Send + Sync + 'static> RpcModule<Context> {
 
 						match response {
 							SubscriptionCloseResponse::Notif(msg) => {
-								let json = sub_message_to_json(msg, SubNotifResultOrError::Result, &sub_id, method);
+								let json = sub_message_to_json(msg, &sub_id, method);
 								let _ = method_sink.send(json).await;
 							}
-							SubscriptionCloseResponse::NotifErr(msg) => {
-								let json = sub_message_to_json(msg, SubNotifResultOrError::Error, &sub_id, method);
+							SubscriptionCloseResponse::NotifErr(err) => {
+								let json = sub_err_to_json(err, sub_id, method);
 								let _ = method_sink.send(json).await;
 							}
 							SubscriptionCloseResponse::None => (),
@@ -913,7 +912,7 @@ impl<Context: Send + Sync + 'static> RpcModule<Context> {
 	///         let sink = pending.accept().await.unwrap();
 	///         let sum = val + (*ctx);
 	///
-	///         let msg = SubscriptionMessage::from_json(&sum).unwrap();
+	///         let msg = serde_json::value::to_raw_value(&sum).unwrap();
 	///
 	///         // This fails only if the connection is closed
 	///         sink.send(msg).await.unwrap();
