@@ -166,10 +166,11 @@ mod builtins {
     use super::*;
 
     use crate::error::ErrorKind;
+    use crate::format_utils::{format_filter, FormatStyle};
     use crate::utils::{safe_sort, splitn_whitespace};
     use crate::value::merge_object::{MergeDict, MergeSeq};
-    use crate::value::ops::{self, as_f64};
-    use crate::value::{Enumerator, Kwargs, Object, ObjectRepr, ValueKind, ValueRepr};
+    use crate::value::ops::{self, as_f64, LenIterWrap};
+    use crate::value::{Enumerator, Kwargs, Object, ObjectRepr, Rest, ValueKind, ValueRepr};
     use std::borrow::Cow;
     use std::cmp::Ordering;
     use std::fmt::Write;
@@ -376,7 +377,20 @@ mod builtins {
         v.reverse()
     }
 
-    /// Trims a value
+    /// Trims a string.
+    ///
+    /// By default, it trims leading and trailing whitespaces:
+    ///
+    /// ```jinja
+    /// {{ "  non-space characters  " | trim }} -> "non-space characters"
+    /// ```
+    ///
+    /// You can also remove a character sequence.  All the prefixes and suffixes
+    /// matching the sequence are removed:
+    ///
+    /// ```jinja
+    /// {{ "1212foo12bar1212" | trim("12") }} -> "foo12bar"
+    /// ```
     #[cfg_attr(docsrs, doc(cfg(feature = "builtins")))]
     pub fn trim(s: Cow<'_, str>, chars: Option<Cow<'_, str>>) -> String {
         match chars {
@@ -726,7 +740,8 @@ mod builtins {
     /// The filter accepts a few keyword arguments:
     ///
     /// * `case_sensitive`: set to `true` to make the sorting of strings case sensitive.
-    /// * `attribute`: can be set to an attribute or dotted path to sort by that attribute
+    /// * `attribute`: can be set to an attribute or dotted path to sort by that attribute.
+    ///   can be a comma-separated list of attributes forming a composite key like "age, name".
     /// * `reverse`: set to `true` to sort in reverse.
     ///
     /// ```jinja
@@ -736,6 +751,8 @@ mod builtins {
     /// {{ users|sort(attribute="age") }}
     /// # Sort users by age attribute in ascending order.
     /// {{ users|sort(attribute="age", reverse=true) }}
+    /// # Sort cities by their name, and sort those with the same name by their state.
+    /// {{ cities|sort(attribute="name, state") }}
     /// ```
     #[cfg_attr(docsrs, doc(cfg(feature = "builtins")))]
     pub fn sort(state: &State, value: Value, kwargs: Kwargs) -> Result<Value, Error> {
@@ -743,14 +760,45 @@ mod builtins {
             Error::new(ErrorKind::InvalidOperation, "cannot convert value to list").with_source(err)
         }))
         .collect::<Vec<_>>();
+
         let case_sensitive = ok!(kwargs.get::<Option<bool>>("case_sensitive")).unwrap_or(false);
+
         if let Some(attr) = ok!(kwargs.get::<Option<&str>>("attribute")) {
-            safe_sort(&mut items, |a, b| {
-                match (a.get_path(attr), b.get_path(attr)) {
-                    (Ok(a), Ok(b)) => cmp_helper(&a, &b, case_sensitive),
-                    _ => Ordering::Equal,
-                }
-            })?;
+            let keys: Vec<_> = attr
+                .split(',')
+                .filter_map(|key| {
+                    let trimmed = key.trim();
+                    if !key.is_empty() {
+                        Some(trimmed)
+                    } else {
+                        None
+                    }
+                })
+                .collect();
+
+            if keys.len() > 1 {
+                // More than one keys
+                safe_sort(&mut items, |a, b| {
+                    let key_a = Value::from_iter(
+                        keys.iter()
+                            .map(|k| a.get_path_or_default(k, &Value::UNDEFINED)),
+                    );
+                    let key_b = Value::from_iter(
+                        keys.iter()
+                            .map(|k| b.get_path_or_default(k, &Value::UNDEFINED)),
+                    );
+                    cmp_helper(&key_a, &key_b, case_sensitive)
+                })?;
+            } else {
+                // Fast path for a more common case of single key
+                let key = if !keys.is_empty() { keys[0] } else { attr };
+                safe_sort(&mut items, |a, b| {
+                    match (a.get_path(key), b.get_path(key)) {
+                        (Ok(a), Ok(b)) => cmp_helper(&a, &b, case_sensitive),
+                        _ => Ordering::Equal,
+                    }
+                })?;
+            }
         } else {
             safe_sort(&mut items, |a, b| cmp_helper(a, b, case_sensitive))?;
         }
@@ -1518,6 +1566,82 @@ mod builtins {
         }
     }
 
+    /// Zip multiple iterables into tuples.
+    ///
+    /// This filter works like the Python `zip` function. It takes one or more
+    /// iterables and returns an iterable of tuples where each tuple contains
+    /// one element from each input iterable. The iteration stops when the
+    /// shortest iterable is exhausted.
+    ///
+    /// ```jinja
+    /// {{ [1, 2, 3]|zip(['a', 'b', 'c']) }}
+    /// -> [(1, 'a'), (2, 'b'), (3, 'c')]
+    ///
+    /// {{ [1, 2]|zip(['a', 'b', 'c'], ['x', 'y', 'z']) }}
+    /// -> [(1, 'a', 'x'), (2, 'b', 'y')]
+    /// ```
+    #[cfg_attr(docsrs, doc(cfg(feature = "builtins")))]
+    pub fn zip(_state: &State, value: Value, others: Rest<Value>) -> Result<Value, Error> {
+        let all_values = Some(value).into_iter().chain(others.0).collect::<Vec<_>>();
+
+        // Validate all values are iterable and calculate minimum length
+        let mut known_len: Option<usize> = None;
+        for val in &all_values {
+            match val.try_iter() {
+                Ok(_) => {
+                    // If all values have known lengths, track the minimum
+                    if let Some(len) = val.len() {
+                        known_len = Some(match known_len {
+                            None => len,
+                            Some(current_min) => current_min.min(len),
+                        });
+                    } else {
+                        // If any value doesn't have a known length, we can't know the zip length
+                        known_len = None;
+                        break;
+                    }
+                }
+                Err(_) => {
+                    return Err(Error::new(
+                        ErrorKind::InvalidOperation,
+                        format!("zip filter argument must be iterable, got {}", val.kind()),
+                    ));
+                }
+            }
+        }
+
+        Ok(Value::make_object_iterable(all_values, move |values| {
+            let iter = std::iter::from_fn({
+                let mut iters = values
+                    .iter()
+                    .map(|val| val.try_iter().ok())
+                    .collect::<Option<Vec<_>>>()
+                    .unwrap_or_default();
+
+                move || {
+                    if iters.is_empty() {
+                        return None;
+                    }
+
+                    let mut tuple = Vec::with_capacity(iters.len());
+                    for iter in &mut iters {
+                        match iter.next() {
+                            Some(val) => tuple.push(val),
+                            None => return None,
+                        }
+                    }
+                    Some(Value::from(tuple))
+                }
+            });
+
+            if let Some(len) = known_len {
+                Box::new(LenIterWrap(len, iter)) as Box<dyn Iterator<Item = Value> + Send + Sync>
+            } else {
+                Box::new(iter) as Box<dyn Iterator<Item = Value> + Send + Sync>
+            }
+        }))
+    }
+
     /// Pretty print a variable.
     ///
     /// This is useful for debugging as it better shows what's inside an object.
@@ -1525,6 +1649,30 @@ mod builtins {
     pub fn pprint(value: &Value) -> String {
         format!("{value:#?}")
     }
+
+    /// Apply the given values to a [printf-style] format string.
+    ///
+    /// ```jinja
+    /// {{ "%s, %s!"|format(greeting, name) }}
+    /// -> Hello, World!
+    /// ```
+    ///
+    /// In many cases, the [str.format()] style could be more convenient than the
+    /// printf-style formatting:
+    ///
+    /// ```jinja
+    /// {{ "{}, {name}!".format(greeting, name="Alice") }}
+    /// -> Hello, Alice!
+    /// ```
+    ///
+    /// This option is available through `minijinja-contrib`'s `pycompat` feature.
+    ///
+    /// [printf-style]: https://docs.python.org/3/library/stdtypes.html#printf-style-string-formatting
+    /// [str.format()]: https://docs.python.org/3/library/string.html#format-string-syntax
+    #[cfg_attr(docsrs, doc(cfg(feature = "builtins")))]
+    pub fn format(format_str: &str, format_args: Rest<Value>) -> Result<String, Error> {
+        format_filter(FormatStyle::Printf, format_str, &format_args)
+    }
 }
 
 #[cfg(feature = "builtins")]
