@@ -32,10 +32,10 @@ pub use indicatif::{
     ProgressFormatter,
 };
 use itertools::Itertools;
-use rattler_cache::package_cache::{CacheLock, CacheReporter};
+use rattler_cache::package_cache::{CacheMetadata, CacheReporter};
 use rattler_conda_types::{
     prefix_record::{Link, LinkType},
-    MatchSpec, PackageName, Platform, PrefixRecord, RepoDataRecord,
+    MatchSpec, PackageName, PackageNameMatcher, Platform, PrefixRecord, RepoDataRecord,
 };
 use rattler_networking::retry_policies::default_retry_policy;
 use rattler_networking::LazyClient;
@@ -475,6 +475,13 @@ impl Installer {
             )
         });
 
+        // Acquire a global lock on the package cache for the entire installation.
+        // This significantly reduces overhead by avoiding per-package locking.
+        let _global_cache_lock = package_cache
+            .acquire_global_lock()
+            .await
+            .map_err(InstallerError::FailedToAcquireCacheLock)?;
+
         // Construct a driver.
         let driver = InstallDriver::builder()
             .execute_link_scripts(self.execute_link_scripts)
@@ -503,7 +510,7 @@ impl Installer {
 
         // Preprocess the transaction
         let pre_process_result = driver
-            .pre_process(&transaction, &prefix)
+            .pre_process(&transaction, &prefix, self.reporter.as_deref())
             .map_err(InstallerError::PreProcessingFailed)?;
 
         if let Some(reporter) = &self.reporter {
@@ -581,7 +588,7 @@ impl Installer {
                             let cache_index = r.on_populate_cache_start(operation_idx, &record);
                             (r, cache_index)
                         });
-                        let cache_lock = populate_cache(
+                        let cache_metadata = populate_cache(
                             &record,
                             downloader,
                             &package_cache,
@@ -591,7 +598,7 @@ impl Installer {
                         if let Some((reporter, index)) = populate_cache_report {
                             reporter.on_populate_cache_complete(index);
                         }
-                        Ok((cache_lock, record))
+                        Ok((cache_metadata, record))
                     })
                     .map_err(JoinError::try_into_panic)
                     .map(|res| match res {
@@ -606,18 +613,28 @@ impl Installer {
                 };
 
                 // Install the package if it was fetched.
-                if let Some((cache_lock, record)) = package_to_install.await? {
+                if let Some((cache_metadata, record)) = package_to_install.await? {
                     let reporter = reporter
                         .as_deref()
                         .map(|r| (r, r.on_link_start(operation_idx, &record)));
                     let requested_spec = spec_mapping_ref
                         .and_then(|mapping| mapping.get(&record.package_record.name).cloned())
                         .unwrap_or_default();
+
+                    // Reuse index_json and paths_json from cache validation if available
+                    let mut install_options = base_install_options.clone();
+                    if let Some(index_json) = cache_metadata.index_json() {
+                        install_options.index_json = Some(index_json.clone());
+                    }
+                    if let Some(paths_json) = cache_metadata.paths_json() {
+                        install_options.paths_json = Some(paths_json.clone());
+                    }
+
                     link_package(
                         &record,
                         prefix,
-                        cache_lock.path(),
-                        base_install_options.clone(),
+                        cache_metadata.path(),
+                        install_options,
                         driver,
                         requested_spec,
                     )
@@ -659,7 +676,8 @@ impl Installer {
         drop(pending_link_futures);
 
         // Post process the transaction
-        let post_process_result = driver.post_process(&transaction, &prefix)?;
+        let post_process_result =
+            driver.post_process(&transaction, &prefix, self.reporter.as_deref())?;
 
         if let Some(reporter) = &self.reporter {
             reporter.on_transaction_complete();
@@ -691,6 +709,9 @@ async fn link_package(
 
     let (tx, rx) = tokio::sync::oneshot::channel();
 
+    // Since we use the `Prefix` type, the conda-meta folder is guaranteed to exist
+    let conda_meta_path = target_prefix.path().join("conda-meta");
+
     rayon::spawn_fifo(move || {
         let inner = move || {
             // Link the contents of the package into the prefix.
@@ -715,21 +736,7 @@ async fn link_package(
                 ..PrefixRecord::from_repodata_record(record.clone(), paths)
             };
 
-            let conda_meta_path = target_prefix.path().join("conda-meta");
-            std::fs::create_dir_all(&conda_meta_path).map_err(|e| {
-                InstallerError::IoError("failed to create conda-meta directory".to_string(), e)
-            })?;
-
-            let pkg_meta_path = format!(
-                "{}-{}-{}.json",
-                prefix_record
-                    .repodata_record
-                    .package_record
-                    .name
-                    .as_normalized(),
-                prefix_record.repodata_record.package_record.version,
-                prefix_record.repodata_record.package_record.build
-            );
+            let pkg_meta_path = prefix_record.file_name();
             prefix_record
                 .write_to_path(conda_meta_path.join(&pkg_meta_path), true)
                 .map_err(|e| {
@@ -752,7 +759,7 @@ async fn populate_cache(
     downloader: LazyClient,
     cache: &PackageCache,
     reporter: Option<(Arc<dyn Reporter>, usize)>,
-) -> Result<CacheLock, InstallerError> {
+) -> Result<CacheMetadata, InstallerError> {
     struct CacheReporterBridge {
         reporter: Arc<dyn Reporter>,
         cache_index: usize,
@@ -854,13 +861,13 @@ fn update_requested_specs_in_json(
 /// - The value is a vector of string representations of all matching
 ///   `MatchSpecs`
 ///
-/// `MatchSpecs` without names are skipped.
-/// For multiple `MatchSpecs` with the same package name, all are collected.
+/// Only `MatchSpec`s that have a `PackageNameMatcher::Exact` are included.
+/// For multiple `MatchSpec`s with the same package name, all are collected.
 fn create_spec_mapping(specs: &[MatchSpec]) -> std::collections::HashMap<PackageName, Vec<String>> {
     let mut mapping = std::collections::HashMap::new();
 
     for spec in specs {
-        if let Some(name) = &spec.name {
+        if let Some(PackageNameMatcher::Exact(name)) = &spec.name {
             mapping
                 .entry(name.clone())
                 .or_insert_with(Vec::new)
