@@ -4,11 +4,60 @@ use rattler_conda_types::{
     ChannelUrl, MatchSpec, Matches, NamelessMatchSpec, PackageRecord, RepoDataRecord,
 };
 use rattler_digest::Sha256Hash;
+use serde::{Deserialize, Serialize};
 use std::collections::BTreeMap;
-use std::{borrow::Cow, cmp::Ordering, hash::Hash};
+use std::{borrow::Cow, cmp::Ordering, fmt::Display, hash::Hash};
 use typed_path::Utf8TypedPathBuf;
 use url::Url;
 
+/// Represents a conda-build variant value.
+///
+/// Variants are used in conda-build to specify different build configurations.
+/// They can be strings (e.g., "3.11" for python version), integers (e.g., 1 for feature flags),
+/// or booleans (e.g., true/false for optional features).
+#[derive(Clone, Debug, PartialEq, Eq, Hash, Serialize, Deserialize)]
+#[serde(untagged)]
+pub enum VariantValue {
+    /// String variant value (most common, e.g., python version "3.11")
+    String(String),
+    /// Integer variant value (e.g., for numeric feature flags)
+    Int(i64),
+    /// Boolean variant value (e.g., for on/off features)
+    Bool(bool),
+}
+
+impl PartialOrd for VariantValue {
+    fn partial_cmp(&self, other: &Self) -> Option<Ordering> {
+        Some(self.cmp(other))
+    }
+}
+
+impl Ord for VariantValue {
+    fn cmp(&self, other: &Self) -> Ordering {
+        #[allow(clippy::match_same_arms)]
+        match (self, other) {
+            (VariantValue::String(a), VariantValue::String(b)) => a.cmp(b),
+            (VariantValue::Int(a), VariantValue::Int(b)) => a.cmp(b),
+            (VariantValue::Bool(a), VariantValue::Bool(b)) => a.cmp(b),
+            // Define ordering between different types for deterministic sorting
+            (VariantValue::String(_), _) => Ordering::Less,
+            (_, VariantValue::String(_)) => Ordering::Greater,
+            (VariantValue::Int(_), VariantValue::Bool(_)) => Ordering::Less,
+            (VariantValue::Bool(_), VariantValue::Int(_)) => Ordering::Greater,
+        }
+    }
+}
+
+impl Display for VariantValue {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            VariantValue::String(s) => write!(f, "{s}"),
+            VariantValue::Int(i) => write!(f, "{i}"),
+            VariantValue::Bool(b) => write!(f, "{b}"),
+        }
+    }
+}
+
 /// A locked conda dependency can be either a binary package or a source
 /// package.
 ///
@@ -157,12 +206,16 @@ pub enum GitShallowSpec {
     Rev,
 }
 
-/// Package build source kind.
+/// Package build source location for reproducible builds.
+///
+/// This stores the exact source location information needed to
+/// reproducibly build a package from source. Used by pixi build
+/// and other package building tools.
 #[derive(Clone, Debug, PartialEq, Eq, Hash)]
-pub enum PackageBuildSourceKind {
-    /// Git repository source with specific revision
+pub enum PackageBuildSource {
+    /// Git repository source with specific revision.
     Git {
-        /// The repository URL
+        /// The repository URL.
         url: Url,
         /// Shallow specification of repository head to use.
         ///
@@ -170,37 +223,23 @@ pub enum PackageBuildSourceKind {
         spec: Option<GitShallowSpec>,
         /// The specific git revision.
         rev: String,
+        /// Subdirectory on which focus on.
+        subdir: Option<Utf8TypedPathBuf>,
     },
-    /// URL-based archive source with content hash
+    /// URL-based archive source with content hash.
     Url {
-        /// The URL to the archive
+        /// The URL to the archive.
         url: Url,
-        /// The SHA256 hash of the archive content
+        /// The SHA256 hash of the archive content.
         sha256: Sha256Hash,
+        /// Subdirectory to use.
+        subdir: Option<Utf8TypedPathBuf>,
+    },
+    /// Source is some local path.
+    Path {
+        /// Actual path.
+        path: Utf8TypedPathBuf,
     },
-}
-
-/// Package build source location for reproducible builds.
-///
-/// This stores the exact source location information needed to
-/// reproducibly build a package from source. Used by pixi build
-/// and other package building tools.
-///
-/// There are 3 different types of locations: path, git, url
-/// (archive). We store only git and url sources, since path-based
-/// sources can change over time and would require expensive
-/// computation of directory file hashes for reproducibility.
-///
-/// For git sources we store the repository url and exact revision.
-/// For url sources we store the archive url and its content hash.
-///
-/// For both kinds we store subdirectory.
-#[derive(Clone, Debug, PartialEq, Eq, Hash)]
-pub struct PackageBuildSource {
-    /// Kind of source we fetch.
-    pub kind: PackageBuildSourceKind,
-    /// Subdirectory of the source from which build starts.
-    pub subdirectory: Option<Utf8TypedPathBuf>,
 }
 
 /// Information about a source package stored in the lock-file.
@@ -212,6 +251,11 @@ pub struct CondaSourceData {
     /// The location of the package. This can be a URL or a local path.
     pub location: UrlOrPath,
 
+    /// Conda-build variants used to disambiguate between multiple source packages
+    /// at the same location. This is a map from variant name to variant value.
+    /// Optional field added in lock file format V6 (made required in V7).
+    pub variants: Option<BTreeMap<String, VariantValue>>,
+
     /// Package build source location for reproducible builds
     pub package_build_source: Option<PackageBuildSource>,
 
@@ -354,7 +398,7 @@ impl Matches<MatchSpec> for CondaPackageData {
     fn matches(&self, spec: &MatchSpec) -> bool {
         // Check if the name matches
         if let Some(name) = &spec.name {
-            if name != &self.record().name {
+            if !name.matches(&self.record().name) {
                 return false;
             }
         }
