@@ -3,6 +3,7 @@
 //! Networking utilities for Rattler, specifically authenticating requests
 pub use authentication_middleware::AuthenticationMiddleware;
 pub use authentication_storage::{authentication::Authentication, storage::AuthenticationStorage};
+pub use lazy_client::LazyClient;
 pub use mirror_middleware::MirrorMiddleware;
 pub use oci_middleware::OciMiddleware;
 
@@ -19,6 +20,7 @@ pub use s3_middleware::S3Middleware;
 pub mod authentication_middleware;
 pub mod authentication_storage;
 
+mod lazy_client;
 pub mod mirror_middleware;
 pub mod oci_middleware;
 pub mod retry_policies;
