@@ -10,6 +10,7 @@
 
 #![deny(missing_docs)]
 
+mod conditional_requirement;
 pub mod conflict;
 pub(crate) mod internal;
 mod requirement;
@@ -23,8 +24,9 @@ use std::{
     fmt::{Debug, Display},
 };
 
+pub use conditional_requirement::{Condition, ConditionalRequirement, LogicalOperator};
 pub use internal::{
-    id::{NameId, SolvableId, StringId, VersionSetId, VersionSetUnionId},
+    id::{ConditionId, NameId, SolvableId, StringId, VersionSetId, VersionSetUnionId},
     mapping::Mapping,
 };
 use itertools::Itertools;
@@ -99,6 +101,13 @@ pub trait Interner {
         &self,
         version_set_union: VersionSetUnionId,
     ) -> impl Iterator<Item = VersionSetId>;
+
+    /// Resolves how a condition should be represented in the solver.
+    ///
+    /// Internally, the solver uses `ConditionId` to represent conditions. This
+    /// allows implementers to have a custom representation for conditions that
+    /// differ from the representation of the solver.
+    fn resolve_condition(&self, condition: ConditionId) -> Condition;
 }
 
 /// Defines implementation specific behavior for the solver and a way for the
@@ -226,7 +235,7 @@ pub struct KnownDependencies {
         feature = "serde",
         serde(default, skip_serializing_if = "Vec::is_empty")
     )]
-    pub requirements: Vec<Requirement>,
+    pub requirements: Vec<ConditionalRequirement>,
 
     /// Defines additional constraints on packages that may or may not be part
     /// of the solution. Different from `requirements`, packages in this set
