@@ -13,6 +13,11 @@ use std::time::SystemTime;
 pub mod boxed;
 pub mod impls;
 
+pub use sys_traits_macros::auto_impl;
+
+use self::boxed::BoxedFsFile;
+use self::boxed::BoxedFsMetadataValue;
+
 // #### ENVIRONMENT ####
 
 // == EnvCurrentDir ==
@@ -116,6 +121,12 @@ pub trait EnvHomeDir {
   fn env_home_dir(&self) -> Option<PathBuf>;
 }
 
+// == EnvProgramsDir ==
+
+pub trait EnvProgramsDir {
+  fn env_programs_dir(&self) -> Option<PathBuf>;
+}
+
 // == EnvTempDir ==
 
 pub trait EnvTempDir {
@@ -473,6 +484,30 @@ pub trait FsHardLink: BaseFsHardLink {
 
 impl<T: BaseFsHardLink> FsHardLink for T {}
 
+// == FsCreateJunction ==
+
+pub trait BaseFsCreateJunction {
+  #[doc(hidden)]
+  fn base_fs_create_junction(
+    &self,
+    original: &Path,
+    junction: &Path,
+  ) -> io::Result<()>;
+}
+
+pub trait FsCreateJunction: BaseFsCreateJunction {
+  /// Creates an NTFS junction.
+  fn fs_create_junction(
+    &self,
+    original: impl AsRef<Path>,
+    junction: impl AsRef<Path>,
+  ) -> io::Result<()> {
+    self.base_fs_create_junction(original.as_ref(), junction.as_ref())
+  }
+}
+
+impl<T: BaseFsCreateJunction> FsCreateJunction for T {}
+
 // == FsMetadata ==
 
 #[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
@@ -632,6 +667,7 @@ pub trait FsFile:
   + std::io::Seek
   + FsFileIsTerminal
   + FsFileLock
+  + FsFileMetadata
   + FsFileSetPermissions
   + FsFileSetTimes
   + FsFileSetLen
@@ -641,10 +677,23 @@ pub trait FsFile:
 {
 }
 
+pub trait BoxableFsFile: Sized {
+  fn into_boxed(self) -> BoxedFsFile;
+}
+
+impl<T> BoxableFsFile for T
+where
+  T: FsFile + Sized + 'static,
+{
+  fn into_boxed(self) -> BoxedFsFile {
+    BoxedFsFile(Box::new(self))
+  }
+}
+
 pub trait BaseFsOpen {
   // ideally this wouldn't be constrained, but by not doing
   // this then the type parameters get really out of hand
-  type File: FsFile;
+  type File: FsFile + Sized + 'static;
 
   #[doc(hidden)]
   fn base_fs_open(
@@ -740,7 +789,7 @@ pub trait BaseFsReadDir {
   fn base_fs_read_dir(
     &self,
     path: &Path,
-  ) -> io::Result<Box<dyn Iterator<Item = io::Result<Self::ReadDirEntry>> + '_>>;
+  ) -> io::Result<Box<dyn Iterator<Item = io::Result<Self::ReadDirEntry>>>>;
 }
 
 pub trait FsReadDir: BaseFsReadDir {
@@ -748,8 +797,7 @@ pub trait FsReadDir: BaseFsReadDir {
   fn fs_read_dir(
     &self,
     path: impl AsRef<Path>,
-  ) -> io::Result<Box<dyn Iterator<Item = io::Result<Self::ReadDirEntry>> + '_>>
-  {
+  ) -> io::Result<Box<dyn Iterator<Item = io::Result<Self::ReadDirEntry>>>> {
     self.base_fs_read_dir(path.as_ref())
   }
 }
@@ -1005,6 +1053,14 @@ pub trait FsFileLock {
   fn fs_file_unlock(&mut self) -> io::Result<()>;
 }
 
+pub trait FsFileMetadata {
+  /// Gets the file metadata.
+  ///
+  /// This is boxed because I couldn't figure out how to do
+  /// this well with type parameters.
+  fn fs_file_metadata(&self) -> io::Result<BoxedFsMetadataValue>;
+}
+
 pub trait FsFileSetLen {
   fn fs_file_set_len(&mut self, size: u64) -> io::Result<()>;
 }
