@@ -1,12 +1,30 @@
 #![allow(non_camel_case_types, non_snake_case)]
 
 use crate::decl::*;
-use crate::ole::{privs::*, vts::*};
+use crate::kernel::ffi_types::*;
+use crate::ole::privs::*;
 use crate::prelude::*;
+use crate::vt::*;
+
+/// [`IBindCtx`](crate::IBindCtx) virtual table.
+#[repr(C)]
+pub struct IBindCtxVT {
+	pub IUnknownVT: IUnknownVT,
+	pub RegisterObjectBound: fn(COMPTR, COMPTR) -> HRES,
+	pub RevokeObjectBound: fn(COMPTR, COMPTR) -> HRES,
+	pub ReleaseBoundObjects: fn(COMPTR) -> HRES,
+	pub SetBindOptions: fn(COMPTR, PVOID) -> HRES,
+	pub GetBindOptions: fn(COMPTR, PVOID) -> HRES,
+	pub GetRunningObjectTable: fn(COMPTR, *mut COMPTR) -> HRES,
+	pub RegisterObjectParam: fn(COMPTR, PCSTR, COMPTR) -> HRES,
+	pub GetObjectParam: fn(COMPTR, PCSTR, *mut COMPTR) -> HRES,
+	pub EnumObjectParam: fn(COMPTR, *mut COMPTR) -> HRES,
+	pub RevokeObjectParam: fn(COMPTR, PCSTR) -> HRES,
+}
 
 com_interface! { IBindCtx: "0000000e-0000-0000-c000-000000000046";
 	/// [`IBindCtx`](https://learn.microsoft.com/en-us/windows/win32/api/objidl/nn-objidl-ibindctx)
-	/// COM interface.
+	/// COM interface over [`IBindCtxVT`](crate::vt::IBindCtxVT).
 	///
 	/// Automatically calls
 	/// [`Release`](https://learn.microsoft.com/en-us/windows/win32/api/unknwn/nf-unknwn-iunknown-release)
